@@ -1,21 +1,22 @@
-#' Matrix inverse via Armadillo (Rcpp)
+#' Matrix inverse
 #'
 #' @param A Numeric matrix.
 #' @return The inverse of A.
 #' @keywords internal
 inver <- function(A) {
-  inverseMatrix(as.matrix(A))
+  solve(as.matrix(A))
 }
 
 
-#' Matrix square root via Armadillo (Rcpp)
+#' Matrix square root
 #'
 #' @param A Numeric matrix.
 #' @return The square root of A as a numeric matrix.
 #'   If the result is complex due to rounding, the real part is returned.
+#' @importFrom pracma sqrtm
 #' @keywords internal
 sqrtmat <- function(A) {
-  Re(sqrtMatrix(as.matrix(A)))
+  Re(sqrtm(as.matrix(A))$B)
 }
 
 
@@ -901,6 +902,7 @@ FluxPoint_raw <- function(data, Sig_all_inv, w, D, needReproduce = FALSE) {
   }
 
   cps <- pracma::findpeaks(detectorStats, minpeakheight = D, minpeakdistance = w + 1)[, 2]
+  cps <- sort(cps)
   return(list(shiftIndices = shiftIndices, detectorStats = detectorStats, Projection_list = Projection_list, cps = cps))
 }
 
@@ -1258,6 +1260,7 @@ FluxPoint <- function (data, w, tc, max_iter1, max_iter2, ignoreCross = FALSE, n
   Sig_all_inv <- get_Sigs(w, p, est_diag$Sig_eta, est_diag$Sig_nu, est_diag$Phi, Sig_e1)$Sig_all_inv
   res_new <- FluxPoint_raw(data, Sig_all_inv, w, D, needReproduce = needReproduce)
 
+
   for (i in 1:max_iter1) {
     est_diag <- estimate_RWVAR_cp_heter(data, CPs = res_new$cps, phiLower = phiLower, phiUpper = phiUpper, sigetaUpper = sigetaUpper)
     Sig_e1 <- get_Sig_e1_approx(est_diag$Sig_nu, est_diag$Phi)
@@ -1276,7 +1279,6 @@ FluxPoint <- function (data, w, tc, max_iter1, max_iter2, ignoreCross = FALSE, n
 
   if (ignoreCross) {
     if (!is.null(res_new$cps)) {
-      res_new$cps <- sort(res_new$cps)
       shiftIndices <- matrix(res_new$shiftIndices[res_new$cps, ], nrow = length(res_new$cps))
       for (i in 1:nrow(shiftIndices)) {
         cps_at[[i]] <- which(shiftIndices[i, ] != 0)
@@ -1287,7 +1289,6 @@ FluxPoint <- function (data, w, tc, max_iter1, max_iter2, ignoreCross = FALSE, n
   }
 
   if (p == 1) {
-    res_new$cps <- sort(res_new$cps)
     muhats <- estimate_musseg(data, res_new$cps, est_diag$Sig_eta, est_diag$Sig_nu, est_diag$Phi, Sig_e1)
     return(list(cps = res_new$cps, Sig_eta_hat = est_diag$Sig_eta, Sig_nu_hat = est_diag$Sig_nu, Phi_hat = est_diag$Phi, muhats = muhats, detectorStats = res_new$detectorStats))
   }
@@ -1300,6 +1301,7 @@ FluxPoint <- function (data, w, tc, max_iter1, max_iter2, ignoreCross = FALSE, n
   Sig_all_inv <- get_Sigs(w, p, est_diag$Sig_eta, est_nondiag$Sig_nu_hat, est_nondiag$Phi_hat, Sig_e1)$Sig_all_inv
   res_new <- FluxPoint_raw(data, Sig_all_inv, w, D, needReproduce = needReproduce)
 
+
   for (i in 1:max_iter2) {
     muhats <- estimate_musseg(data, res_new$cps, est_diag$Sig_eta, est_nondiag$Sig_nu_hat, est_nondiag$Phi_hat, Sig_e1)
     epsilons <- data - muhats
@@ -1315,7 +1317,6 @@ FluxPoint <- function (data, w, tc, max_iter1, max_iter2, ignoreCross = FALSE, n
   }
 
   if (!is.null(res_new$cps)) {
-    res_new$cps <- sort(res_new$cps)
     shiftIndices <- matrix(res_new$shiftIndices[res_new$cps, ], nrow = length(res_new$cps))
     for (i in 1:nrow(shiftIndices)) {
       cps_at[[i]] <- which(shiftIndices[i, ] != 0)
@@ -1332,7 +1333,6 @@ FluxPoint <- function (data, w, tc, max_iter1, max_iter2, ignoreCross = FALSE, n
 
 
 
-
 #' Plot multivariate time series with detected change points and estimated means
 #'
 #' @description
